==> sanjagh_flutter-0.0.2.tar.gz: lib/sanjagh_flutter.dart <==
import 'dart:async';

import 'package:flutter/services.dart';
import 'package:flutter/material.dart';
import 'package:flutter/foundation.dart';

typedef void AdListener(AdEvent event);

enum AdEvent {
  loaded,
  failedToLoad,
  noNetwork,
  noAd,
  adClosed,
}

abstract class MobileAd {
  int get id => hashCode;

  AdListener adListener;
  static final Map<int, MobileAd> _allAds = <int, MobileAd>{};
  String adUnitId;

  MobileAd({this.adListener, this.adUnitId}) {
    _allAds[id] = this;
  }

  Future<bool> show() {
    return _invokeBooleanMethod("showAd", <String, dynamic>{
      'id': id,
    });
  }

  load();
}

class BannerAd extends MobileAd {
  bool expandable;
  bool transformable;
  int entranceType;

  BannerAd({
    AdListener adListener,
    String adUnitId,
    this.expandable = false,
    this.entranceType = 0,
    this.transformable = false,
  }) : super(adUnitId: adUnitId, adListener: adListener);

  @override
  load() {
    _invokeBooleanMethod('showBanner', {
      "adUnitId": adUnitId,
      "id": id,
      "expandable": expandable ?? false,
      "transformable": transformable ?? false,
      "entranceType": entranceType ?? 0,
    });
  }
}

class InterstitialAd extends MobileAd {
  /// Create an Interstitial.
  ///
  /// A valid [adUnitId] is required.
  InterstitialAd({
    String adUnitId,
//    MobileAdTargetingInfo targetingInfo,
    AdListener adListener,
  }) : super(adUnitId: adUnitId, adListener: adListener);

  /// A platform-specific AdMob test ad unit ID for interstitials. This ad unit
  /// has been specially configured to always return test ads, and developers
  /// are encouraged to use it while building and testing their apps.

  @override
  Future<bool> load() {
    return _invokeBooleanMethod("loadInterstitialAd", <String, dynamic>{
      'id': id,
      'adUnitId': adUnitId,
    });
  }
}

class NativeExpressAd extends MobileAd {
  NativeExpressAd({
    AdListener adListener,
    String adUnitId,
  }) : super(adUnitId: adUnitId, adListener: adListener);

  @override
  load() {
    _invokeBooleanMethod('showNativeExpress', {
      "adUnitId": adUnitId,
      "id": id,
    });
  }
}

class SanjaghFlutterPlugin {
  final MethodChannel _channel = const MethodChannel('flutter_sdk');

  static const int MARKET_GOOGLE_PLAY = 1;
  static const int MARKET_CAFE_BAZAAR = 2;
  static const int MARKET_MYKET = 3;
  static const int MARKET_IRAN_APPS = 4;
  static const int MARKET_AVVAL_MARKET = 5;
  static const int MARKET_CANDO = 6;
  static const int MARKET_CHARKHONEH = 7;
  static const int MARKET_OTHER = 100;

  static const int EXPANDABLE_AD_OPTIONS_ENTRANCE_TYPE_NONE = 0;
  static const int EXPANDABLE_AD_OPTIONS_ENTRANCE_TYPE_DOWN = 1;
  static const int EXPANDABLE_AD_OPTIONS_ENTRANCE_TYPE_UP = 2;
  static const int EXPANDABLE_AD_OPTIONS_ENTRANCE_TYPE_FADE = 3;

  SanjaghFlutterPlugin.private() {
    _channel.setMethodCallHandler(_methodHandler);
  }

  static final SanjaghFlutterPlugin _instance = SanjaghFlutterPlugin.private();

  static SanjaghFlutterPlugin get instance => _instance;

  Future<dynamic> _methodHandler(MethodCall call) {
    assert(call.arguments is Map);
    Map<dynamic, dynamic> argumentsMap = call.arguments;
    int id = argumentsMap['id'];
    if (id != null && MobileAd._allAds[id] != null) {
      MobileAd ad = MobileAd._allAds[id];
      AdEvent adEvent = _methodToAdEvent[call.method];
      if (AdEvent != null && ad.adListener != null) {
        ad.adListener(adEvent);
      }
    }

    return Future<dynamic>.value(null);
  }

  static const Map<String, AdEvent> _methodToAdEvent = <String, AdEvent>{
    'onAdLoaded': AdEvent.loaded,
    'onAdFailedToLoad': AdEvent.failedToLoad,
    'onNoNetwork': AdEvent.noNetwork,
    'onNoAd': AdEvent.noAd,
    'onAdClosed': AdEvent.adClosed,
  };

  void initialize(String appId, {int market, String primaryColor, String userIdentifier}) {
    _channel.invokeMethod('initialize', {"appId": appId});
    if (market != null) {
      _channel.invokeMethod('setMarket', {"market": market});
    }

    if (primaryColor != null) {
      _channel.invokeMethod('setPrimaryColor', {"color": primaryColor});
    }

    if (userIdentifier != null) {
      _channel.invokeMethod('setUserIdentifier', {"userIdentifier": userIdentifier});
    }
  }
}

Future<bool> _invokeBooleanMethod(String method, [dynamic arguments]) async {
  final bool result = await SanjaghFlutterPlugin.instance._channel.invokeMethod(
    method,
    arguments,
  );
  return result;
}

class BannerAdView extends StatefulWidget {
  final AdListener adListener;
  final String adUnitId;

  const BannerAdView({
    Key key,
    this.adListener,
    this.adUnitId,
  });

  @override
  State<StatefulWidget> createState() {
    return _BannerAdViewState();
  }
}

class _BannerAdViewState extends State<BannerAdView> {
  @override
  Widget build(BuildContext context) {
    if (defaultTargetPlatform == TargetPlatform.android) {
      return AndroidView(
        viewType: "com.sanjagh.sdk/banner",
        onPlatformViewCreated: _onPlatformViewCreated,
        creationParams: {"adUnitId":widget.adUnitId},
        creationParamsCodec: JSONMessageCodec(),
      );
    }
    return Text('$defaultTargetPlatform is not yet supported by the sanjagh flutter plugin');
  }

  void _onPlatformViewCreated(int id) {
    new BannerAdViewController._(id, widget.adListener);
  }
}

class BannerAdViewController {
  MethodChannel _channel;
  AdListener _adListener;

  Future<dynamic> _methodHandler(MethodCall call) {
    print("method");
    AdEvent adEvent = _methodToAdEvent[call.method];
    if (AdEvent != null && _adListener != null) {
      _adListener(adEvent);
    }

    return Future<dynamic>.value(null);
  }

  static const Map<String, AdEvent> _methodToAdEvent = <String, AdEvent>{
    'onAdLoaded': AdEvent.loaded,
    'onAdFailedToLoad': AdEvent.failedToLoad,
    'onNoNetwork': AdEvent.noNetwork,
    'onNoAd': AdEvent.noAd,
    'onAdClosed': AdEvent.adClosed,
  };

  BannerAdViewController._(int id, this._adListener) {
    _channel = new MethodChannel('com.sanjagh.sdk/banner_$id');
    ;
    _channel.setMethodCallHandler(_methodHandler);
  }

}

==> sanjagh_flutter-0.0.3.tar.gz: lib/sanjagh_flutter.dart <==
import 'dart:async';

import 'package:flutter/services.dart';
import 'package:flutter/material.dart';
import 'package:flutter/foundation.dart';

typedef void AdListener(AdEvent event,int errorCode);

enum AdEvent {
  loaded,
  failedToLoad,
  noNetwork,
  noAd,
  adClosed,
}

abstract class MobileAd {
  int get id => hashCode;

  AdListener adListener;
  static final Map<int, MobileAd> _allAds = <int, MobileAd>{};
  String adUnitId;

  MobileAd({this.adListener, this.adUnitId}) {
    _allAds[id] = this;
  }

  Future<bool> show() {
    return _invokeBooleanMethod("showAd", <String, dynamic>{
      'id': id,
    });
  }

  load();
}

class BannerAd extends MobileAd {
  bool expandable;
  bool transformable;
  int entranceType;

  BannerAd({
    AdListener adListener,
    String adUnitId,
    this.expandable = false,
    this.entranceType = 0,
    this.transformable = false,
  }) : super(adUnitId: adUnitId, adListener: adListener);

  @override
  load() {
    _invokeBooleanMethod('showBanner', {
      "adUnitId": adUnitId,
      "id": id,
      "expandable": expandable ?? false,
      "transformable": transformable ?? false,
      "entranceType": entranceType ?? 0,
    });
  }
}

class InterstitialAd extends MobileAd {
  /// Create an Interstitial.
  ///
  /// A valid [adUnitId] is required.
  InterstitialAd({
    String adUnitId,
//    MobileAdTargetingInfo targetingInfo,
    AdListener adListener,
  }) : super(adUnitId: adUnitId, adListener: adListener);

  /// A platform-specific AdMob test ad unit ID for interstitials. This ad unit
  /// has been specially configured to always return test ads, and developers
  /// are encouraged to use it while building and testing their apps.

  @override
  Future<bool> load() {
    return _invokeBooleanMethod("loadInterstitialAd", <String, dynamic>{
      'id': id,
      'adUnitId': adUnitId,
    });
  }
}

class NativeExpressAd extends MobileAd {
  NativeExpressAd({
    AdListener adListener,
    String adUnitId,
  }) : super(adUnitId: adUnitId, adListener: adListener);

  @override
  load() {
    _invokeBooleanMethod('showNativeExpress', {
      "adUnitId": adUnitId,
      "id": id,
    });
  }
}

class SanjaghFlutterPlugin {
  final MethodChannel _channel = const MethodChannel('flutter_sdk');

  static const int MARKET_GOOGLE_PLAY = 1;
  static const int MARKET_CAFE_BAZAAR = 2;
  static const int MARKET_MYKET = 3;
  static const int MARKET_IRAN_APPS = 4;
  static const int MARKET_AVVAL_MARKET = 5;
  static const int MARKET_CANDO = 6;
  static const int MARKET_CHARKHONEH = 7;
  static const int MARKET_OTHER = 100;

  static const int EXPANDABLE_AD_OPTIONS_ENTRANCE_TYPE_NONE = 0;
  static const int EXPANDABLE_AD_OPTIONS_ENTRANCE_TYPE_DOWN = 1;
  static const int EXPANDABLE_AD_OPTIONS_ENTRANCE_TYPE_UP = 2;
  static const int EXPANDABLE_AD_OPTIONS_ENTRANCE_TYPE_FADE = 3;

  SanjaghFlutterPlugin.private() {
    _channel.setMethodCallHandler(_methodHandler);
  }

  static final SanjaghFlutterPlugin _instance = SanjaghFlutterPlugin.private();

  static SanjaghFlutterPlugin get instance => _instance;

  Future<dynamic> _methodHandler(MethodCall call) {
    assert(call.arguments is Map);
    Map<dynamic, dynamic> argumentsMap = call.arguments;
    int id = argumentsMap['id'];
    int errorCode = -1;
    if(call.method == 'onAdFailedToLoad'){
      errorCode = argumentsMap['errorCode'];
    }
    if (id != null && MobileAd._allAds[id] != null) {
      MobileAd ad = MobileAd._allAds[id];
      AdEvent adEvent = _methodToAdEvent[call.method];
      if (AdEvent != null && ad.adListener != null) {
        ad.adListener(adEvent, errorCode);
      }
    }

    return Future<dynamic>.value(null);
  }

  static const Map<String, AdEvent> _methodToAdEvent = <String, AdEvent>{
    'onAdLoaded': AdEvent.loaded,
    'onAdFailedToLoad': AdEvent.failedToLoad,
    'onNoNetwork': AdEvent.noNetwork,
    'onNoAd': AdEvent.noAd,
    'onAdClosed': AdEvent.adClosed,
  };

  void initialize(String appId, {int market, String primaryColor, String userIdentifier}) {
    _channel.invokeMethod('initialize', {"appId": appId});
    if (market != null) {
      _channel.invokeMethod('setMarket', {"market": market});
    }

    if (primaryColor != null) {
      _channel.invokeMethod('setPrimaryColor', {"color": primaryColor});
    }

    if (userIdentifier != null) {
      _channel.invokeMethod('setUserIdentifier', {"userIdentifier": userIdentifier});
    }
  }
}

Future<bool> _invokeBooleanMethod(String method, [dynamic arguments]) async {
  final bool result = await SanjaghFlutterPlugin.instance._channel.invokeMethod(
    method,
    arguments,
  );
  return result;
}

class BannerAdView extends StatefulWidget {
  final AdListener adListener;
  final String adUnitId;

  const BannerAdView({
    Key key,
    this.adListener,
    this.adUnitId,
  });

  @override
  State<StatefulWidget> createState() {
    return _BannerAdViewState();
  }
}

class _BannerAdViewState extends State<BannerAdView> {
  @override
  Widget build(BuildContext context) {
    if (defaultTargetPlatform == TargetPlatform.android) {
      return AndroidView(
        viewType: "com.sanjagh.sdk/banner",
        onPlatformViewCreated: _onPlatformViewCreated,
        creationParams: {"adUnitId":widget.adUnitId},
        creationParamsCodec: JSONMessageCodec(),
      );
    }
    return Text('$defaultTargetPlatform is not yet supported by the sanjagh flutter plugin');
  }

  void _onPlatformViewCreated(int id) {
    new BannerAdViewController._(id, widget.adListener);
  }
}

class BannerAdViewController {
  MethodChannel _channel;
  AdListener _adListener;

  Future<dynamic> _methodHandler(MethodCall call) {
    print("method");
    int errorCode = -1;
    if(call.method == "onAdFailedToLoad"){
      errorCode = call.arguments['errorCode'];
    }
    AdEvent adEvent = _methodToAdEvent[call.method];
    if (AdEvent != null && _adListener != null) {
      _adListener(adEvent, errorCode);
    }

    return Future<dynamic>.value(null);
  }

  static const Map<String, AdEvent> _methodToAdEvent = <String, AdEvent>{
    'onAdLoaded': AdEvent.loaded,
    'onAdFailedToLoad': AdEvent.failedToLoad,
    'onNoNetwork': AdEvent.noNetwork,
    'onNoAd': AdEvent.noAd,
    'onAdClosed': AdEvent.adClosed,
  };

  BannerAdViewController._(int id, this._adListener) {
    _channel = new MethodChannel('com.sanjagh.sdk/banner_$id');
    ;
    _channel.setMethodCallHandler(_methodHandler);
  }

}
